(_proxy_py_index)=
# {{ project }} Documentation

```{spelling}
acceptor
acceptors
Changelog
decrypt
decrypted
discoverable
DNS
Facebook
http
macOS
Pre
Py
Scalable
```

```{include} ../README.md
:end-before: (DO-NOT-REMOVE-docs-badges-START)
```

```{include} ../README.md
:start-after: (DO-NOT-REMOVE-docs-badges-END)
```

```{toctree}
:hidden:

changelog
Glossary <glossary>
```

```{toctree}
:caption: Contributing
:hidden:

Code Of Conduct <contributing/code_of_conduct>
contributing/guidelines
contributing/security
Private unsupported (dev) API autodoc <pkg/modules>
```
